==> spring-webmvc-6.1.21-sources.jar: org/springframework/web/servlet/tags/form/package-info.java <==
/**
 * Spring's form tag library for JSP views in Spring's Web MVC framework.
 * For more details on each tag, see the list of tags below with links to
 * individual tag classes, or check the {@code spring-form.tld} file:
 *
 * <ul>
 * <li>{@link org.springframework.web.servlet.tags.form.ButtonTag The button tag}
 * <li>{@link org.springframework.web.servlet.tags.form.CheckboxTag The checkbox tag}
 * <li>{@link org.springframework.web.servlet.tags.form.CheckboxesTag The checkboxes tag}
 * <li>{@link org.springframework.web.servlet.tags.form.ErrorsTag The errors tag}
 * <li>{@link org.springframework.web.servlet.tags.form.FormTag The form tag}
 * <li>{@link org.springframework.web.servlet.tags.form.HiddenInputTag The hidden tag}
 * <li>{@link org.springframework.web.servlet.tags.form.InputTag The input tag}
 * <li>{@link org.springframework.web.servlet.tags.form.LabelTag The label tag}
 * <li>{@link org.springframework.web.servlet.tags.form.OptionTag The option tag}
 * <li>{@link org.springframework.web.servlet.tags.form.OptionsTag The options tag}
 * <li>{@link org.springframework.web.servlet.tags.form.PasswordInputTag The password tag}
 * <li>{@link org.springframework.web.servlet.tags.form.RadioButtonTag The radiobutton tag}
 * <li>{@link org.springframework.web.servlet.tags.form.RadioButtonsTag The radiobuttons tag}
 * <li>{@link org.springframework.web.servlet.tags.form.SelectTag The select tag}
 * <li>{@link org.springframework.web.servlet.tags.form.TextareaTag The textarea tag}
 * </ul>
 */
@NonNullApi
@NonNullFields
package org.springframework.web.servlet.tags.form;

import org.springframework.lang.NonNullApi;
import org.springframework.lang.NonNullFields;

==> spring-webmvc-7.0.2-sources.jar: org/springframework/web/servlet/tags/form/package-info.java <==
/**
 * Spring's form tag library for JSP views in Spring's Web MVC framework.
 * For more details on each tag, see the list of tags below with links to
 * individual tag classes, or check the {@code spring-form.tld} file:
 *
 * <ul>
 * <li>{@link org.springframework.web.servlet.tags.form.ButtonTag The button tag}
 * <li>{@link org.springframework.web.servlet.tags.form.CheckboxTag The checkbox tag}
 * <li>{@link org.springframework.web.servlet.tags.form.CheckboxesTag The checkboxes tag}
 * <li>{@link org.springframework.web.servlet.tags.form.ErrorsTag The errors tag}
 * <li>{@link org.springframework.web.servlet.tags.form.FormTag The form tag}
 * <li>{@link org.springframework.web.servlet.tags.form.HiddenInputTag The hidden tag}
 * <li>{@link org.springframework.web.servlet.tags.form.InputTag The input tag}
 * <li>{@link org.springframework.web.servlet.tags.form.LabelTag The label tag}
 * <li>{@link org.springframework.web.servlet.tags.form.OptionTag The option tag}
 * <li>{@link org.springframework.web.servlet.tags.form.OptionsTag The options tag}
 * <li>{@link org.springframework.web.servlet.tags.form.PasswordInputTag The password tag}
 * <li>{@link org.springframework.web.servlet.tags.form.RadioButtonTag The radiobutton tag}
 * <li>{@link org.springframework.web.servlet.tags.form.RadioButtonsTag The radiobuttons tag}
 * <li>{@link org.springframework.web.servlet.tags.form.SelectTag The select tag}
 * <li>{@link org.springframework.web.servlet.tags.form.TextareaTag The textarea tag}
 * </ul>
 */
@NullMarked
package org.springframework.web.servlet.tags.form;

import org.jspecify.annotations.NullMarked;
